/*js
//==>>>==>>>==>>>==>>>==>>>==>>>==>>>==>>>==>>>==>>>==>>>==>>>==>>>
//
// php Infinite Scroll v1.14
// Copyright (c) phpkobo.com ( http://www.phpkobo.com/ )
// Email : admin@phpkobo.com
// ID : NFSRL-114
// URL : http://www.phpkobo.com/php-infinite-scroll
//
// This software is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; version 2 of the
// License.
//
//==<<<==<<<==<<<==<<<==<<<==<<<==<<<==<<<==<<<==<<<==<<<==<<<==<<<
*/

function initPhpInfiniteScrollApp( $, settings ) {

// To remove the following error message in Chrome:
// "event.layerX and event.layerY are broken and deprecated"
// "in WebKit. They will be removed from the engine in "
// "the near future."
if ( $.event.props.indexOf ) {
	$.event.props.splice($.event.props.indexOf("layerY"),1);
	$.event.props.splice($.event.props.indexOf("layerX"),1);
}

function CCell( jqo_cont ) {
	this.jqo_cont = jqo_cont;
	this.iid = this.getAttr("data-iid",jqo_cont);
	this.idx_curr = 0;
	this.idx_next = 1;
	this.setup();
}

CCell.prototype = {

	getAttr : function( attr_name, jqo ) {
		if (
			( typeof( jqo.attr( attr_name ) ) == 'undefined' ) || 
			( jqo.attr( attr_name ) == '' ) // for Opera
		) {
			return null;
		}
		var s = jqo.attr( attr_name );

		//-- unencode "&quot;" entities
		s = s.replace(new RegExp("&quot;", 'g'), "&");

		return s;
	},

	send : function( data, func ) {
		var _this = this;
		$.ajax({
			url:settings.url_server,
			data:data,
			dataType: 'jsonp',
			success:function(resp) {
				_this.process( resp, func );
			},
			error:function( jqXHR, textStatus, errorThrown ) {
				var s = '[$.ajax.error]\n';
				s += jqXHR.responseText+'\n';
				s += textStatus+'\n';
				s += errorThrown;
				console.log(s);
			}
		});
	},

	onError : function( resp ) {
		var err_prefix = "@ERR:";
		if ( resp.result.substr(0,err_prefix.length) == err_prefix ) {
			alert(resp.result);
		} else {
			console.log(resp.result);
		}
	},

	process : function( resp, func ) {
		if ( resp.result == 'OK' ) {
			func.call( this, resp );
		} else {
			this.onError( resp );
		}
	},

	needMore : function() {
		var win_bottom = $(window).scrollTop() + $(window).height();
		var cell_bottom = this.jqo_cont.offset().top + this.jqo_cont.height();
		return ( cell_bottom - settings.loading_threshold < win_bottom );
	},

	onScroll : function() {
		if ( this.idx_curr < this.idx_next ) {
			if ( this.needMore() ){
				this.idx_curr = this.idx_next;
				this.send( { cmd:'get', iid:this.iid, idx:this.idx_curr }, function( resp ){
					this.update(resp);
				});
			}
		}
	},

	setup : function() {
		var _this = this;

		$(window).bind( "resize", function(){
			_this.onScroll();
		});
		$(window).scroll( function(e) {
			_this.onScroll();
		});
		this.onScroll();
	},

	update : function( resp ) {
		this.jqo_cont.append(resp.html);
		if ( resp.last == 0 ) {
			this.idx_next++;
			this.onScroll();
		}
	}

}

CCellApp = {

	instance_data_sig : "sig-php-infinite-scroll",
	container_class : '.piscr-container',
	prefix_container : '.piscr-container-async',

	isIE7 : function() {
		return (navigator.appVersion.indexOf("MSIE 7.")!=-1);
	},

	escapeDq : function( str ){
		return str.replace(new RegExp('"', 'g'), '\\"' );
	},

	splitToHtmlAndCss : function(icode) {
		var ax = icode.split("</style>");
		var style = "";
		var html = "";
		if ( ax.length == 1 ) {
			style = "";
			html = icode;
		} else {
			style = ax[0];
			html = ax[1];
		}
		return {
			css : style + "</style>",
			html : html
		};
	},

	initApp : function() {
		//console.log("CCellApp.init");
	},

	initInstance : function() {
		var _this = this;
		$( this.container_class ).each( function(){
			if ( $(this).data(_this.instance_data_sig) === undefined ) {
				var obj = new CCell( $(this) ); 
				$(this).data(_this.instance_data_sig,obj);
			}
		});
	},

	initLateInst : function( rec ) {
		var _this = this;
		$(document).ready(function(){
			if ( rec.icode != null ) {//--async
				var rx = _this.splitToHtmlAndCss(rec.icode);// for IE7&8

				if ( !_this.isIE7() ) {
					$(_this.prefix_container+'[data-iid="'+_this.escapeDq(rec.iid)+'"]').html(rx.html);
				} else {
					$(_this.prefix_container).each(function(){
						if ( $(this).attr("data-iid") == rec.iid ) {
							$(this).html(rx.html);
						}
					});
				}

				$('head').append(rx.css);
			}
			_this.initInstance();
		});
	}

};

CCellApp.initApp();

return CCellApp;

};
